
# Type: retrievedOn




URI: [biolink:retrievedOn](https://w3id.org/biolink/vocab/retrievedOn)


## Domain and Range

[SourceFile](SourceFile.md) ->  <sub>OPT</sub> [Date](types/Date.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [SourceFile](SourceFile.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | pav:retrievedOn |

